@@ -25,6 +25,7 @@
 
 #include <AgentInstance>
 #include <AgentManager>
+#include <AkonadiCore/ServerManager>
 #include <kdbusconnectionpool.h>
 #include <AkonadiCore/changerecorder.h>
 #include <AkonadiCore/itemfetchscope.h>
@@ -38,8 +39,8 @@
 #include <QPointer>
 
 NotesAgent::NotesAgent(const QString &id)
-    : Akonadi::AgentBase(id),
-      mAgentInitialized(false)
+    : Akonadi::AgentBase(id)
+    , mAgentInitialized(false)
 {
     Kdelibs4ConfigMigrator migrate(QStringLiteral("notesagent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_notes_agentrc") << QStringLiteral("akonadi_notes_agent.notifyrc"));
@@ -48,7 +49,12 @@ NotesAgent::NotesAgent(const QString &id)
     mNotesManager = new NotesManager(this);
     new NotesAgentAdaptor(this);
     KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/NotesAgent"), this, QDBusConnection::ExportAdaptors);
-    KDBusConnectionPool::threadConnection().registerService(QStringLiteral("org.freedesktop.Akonadi.NotesAgent"));
+    QString service = QStringLiteral("org.freedesktop.Akonadi.NotesAgent");
+    if (Akonadi::ServerManager::hasInstanceIdentifier()) {
+        service += QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
+    }
+
+    KDBusConnectionPool::threadConnection().registerService(service);
 
     setNeedsNetwork(true);
 
@@ -116,11 +122,7 @@ void NotesAgent::showConfigureDialog(qlonglong windowId)
 {
     QPointer<NotesAgentSettingsDialog> dialog = new NotesAgentSettingsDialog;
     if (windowId) {
-#ifndef Q_OS_WIN
         KWindowSystem::setMainWindow(dialog, windowId);
-#else
-        KWindowSystem::setMainWindow(dialog, (HWND)windowId);
-#endif
     }
     if (dialog->exec()) {
         mNotesManager->load();
@@ -187,4 +189,3 @@ int NotesAgent::alarmCheckInterval() const
 }
 
 AKONADI_AGENT_MAIN(NotesAgent)
-
