@@ -27,21 +27,20 @@
 #include <QFont>
 #include <QPoint>
 
-namespace NoteShared
-{
+namespace NoteShared {
 class NOTESHARED_EXPORT NoteDisplayAttribute : public Akonadi::Attribute
 {
 public:
     NoteDisplayAttribute();
     ~NoteDisplayAttribute();
 
-    QByteArray type() const Q_DECL_OVERRIDE;
+    QByteArray type() const override;
 
-    NoteDisplayAttribute *clone() const Q_DECL_OVERRIDE;
+    NoteDisplayAttribute *clone() const override;
 
-    QByteArray serialized() const Q_DECL_OVERRIDE;
+    QByteArray serialized() const override;
 
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    void deserialize(const QByteArray &data) override;
 
     void setBackgroundColor(const QColor &color);
     QColor backgroundColor() const;
