@@ -22,8 +22,7 @@
 #include "noteshared_export.h"
 class QTextCursor;
 class QTextEdit;
-namespace NoteShared
-{
+namespace NoteShared {
 class NOTESHARED_EXPORT NoteEditorUtils
 {
 public:
